@@ -3,7 +3,7 @@ package POE::Component::NonBlockingWrapper::Base;
 use warnings;
 use strict;
 
-our $VERSION = '0.002';
+our $VERSION = '1.001001'; # VERSION
 
 use Carp;
 use POE qw( Filter::Reference  Filter::Line  Wheel::Run );
@@ -14,7 +14,7 @@ sub spawn {
         if @_ & 1;
 
     my %args = @_;
-    
+
     $args{ lc $_ } = delete $args{ $_ } for keys %args;
 
     delete $args{options}
@@ -87,10 +87,10 @@ sub session_id {
 sub _wheel_entry {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     my $sender = $_[SENDER]->ID;
-    
+
     return
         if $self->{shutdown};
-        
+
     my $args;
     if ( ref $_[ARG0] eq 'HASH' ) {
         $args = { %{ $_[ARG0] } };
@@ -99,7 +99,7 @@ sub _wheel_entry {
         carp "First parameter must be a hashref, trying to adjust...";
         $args = { @_[ARG0 .. $#_] };
     }
-    
+
     $args->{ lc $_ } = delete $args->{ $_ }
         for grep { !/^_/ } keys %$args;
 
@@ -124,10 +124,10 @@ sub _wheel_entry {
     else {
         $args->{sender} = $sender;
     }
-    
+
     $kernel->refcount_increment( $args->{sender} => __PACKAGE__ );
     $self->{wheel}->put( $args );
-    
+
     undef;
 }
 
@@ -144,14 +144,14 @@ sub _shutdown {
         unless $self->{alias};
 
     $self->{shutdown} = 1;
-    
+
     $self->{wheel}->shutdown_stdin
         if $self->{wheel};
 }
 
 sub _child_closed {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
-    
+
     carp "_child_closed called (@_[ARG0..$#_])\n"
         if $self->{debug};
 
@@ -175,7 +175,7 @@ sub _child_error {
 }
 
 sub _child_stderr {
-    my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
+    my $self = $_[ OBJECT ];
     carp "_child_stderr: $_[ARG0]\n"
         if $self->{debug};
 
@@ -184,13 +184,13 @@ sub _child_stderr {
 
 sub _child_stdout {
     my ( $kernel, $self, $input ) = @_[ KERNEL, OBJECT, ARG0 ];
-    
+
     my $session = delete $input->{sender};
     my $event   = delete $input->{event};
 
     $kernel->post( $session, $event, $input );
     $kernel->refcount_decrement( $session => __PACKAGE__ );
-    
+
     undef;
 }
 
@@ -203,7 +203,7 @@ sub _wheel {
         binmode STDIN;
         binmode STDOUT;
     }
-    
+
     my $raw;
     my $size = 4096;
     my $filter = POE::Filter::Reference->new;
@@ -237,6 +237,10 @@ sub _methods_define {
 1;
 __END__
 
+=encoding utf8
+
+=for stopwords AnnoCPAN RT thingy PoCo
+
 =head1 NAME
 
 POE::Component::NonBlockingWrapper::Base - POE based base class for non-blocking wrappers around blocking stuff
@@ -295,7 +299,7 @@ L<POE::Component::Generic::Object> for more goodies.
 First read the "DOCUMENTATION FOR YOUR MODULE" section at the bottom, then
 read the "METHODS TO OVERRIDE" and "METHODS TO DEFINE" sections below,
 that should fill you up.
- 
+
 Then you need to C<use base> with this class:
 
     use base 'POE::Component::NonBlockingWrapper::Base';
@@ -322,7 +326,7 @@ constructor (new()) will be available as hashref keys in your object.
 The keys returned will be valid POE events your POE::Component will accept.
 B<Note:> the method/event which will be talking to the non-blocking wheel
 B<must> contain C<_wheel_entry> as the value. Also note that the
-C<shutdown> method/event is premade already so you don't have to worry
+C<shutdown> method/event is pre-made already so you don't have to worry
 about returning it from C<_methods_define()> sub.
 
 The call to C<_methods_define> is made as:
@@ -347,7 +351,7 @@ the POE::Wheel::Run'ed child process before it goes down into listening
 for requests. The first and only element in C<@_> will be your PoCo
 object, note that the (probably) only useful thing from it might be the
 args you've passed to it in the C<new()> method as POE goodies won't be
-preserved for the kiddo proccess. The args can be accessed as hashref keys in
+preserved for the kiddo process. The args can be accessed as hashref keys in
 your PoCo object. You can also stuff it up in the same manner to later
 use those in C<_process_request()> sub (see below)
 
@@ -371,7 +375,7 @@ The C<sender> is used internally and your data assigned to this key will
 get corrupted. The C<_check_args()> must return a true value if arguments
 look fine, if it returns a false value C<_wheel_entry> will abort (by
 doing C<return;>). The first element of C<@_> will be your POE::Component
-object, second elemet will be hashref of arguments passed to the method
+object, second element will be hashref of arguments passed to the method
 mapped to C<_wheel_entry> (see description of C<_methods_define()> above).
 
 =head2 C<_process_request>
@@ -384,7 +388,7 @@ mapped to C<_wheel_entry> (see description of C<_methods_define()> above).
 
 The C<_process_request()> sub is the core of non-blocking doings your
 module would perform. This will be run in the child process so you can
-block it all you want (note, hovewer, than any other requests for this
+block it all you want (note, however, than any other requests for this
 non-blocked thingy will be queried up, we are doing everything with
 I<one> wheel, remember). The first element of C<@_> will be your
 (semi-crippled) PoCo object and the second element of C<@_> will be a
